@@ -6,7 +6,7 @@ use Moo 'with';
 
 with 'Bubblegum::Role::Configuration';
 
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 sub import {
     my $target = caller;
@@ -32,7 +32,7 @@ Bubblegum::Role - Class Component System for Bubblegum via Moo::Role
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -58,6 +58,11 @@ version 0.16
 
     with 'CheckingService';
 
+    has balance => (
+        is      => 'rw',
+        default => 0
+    );
+
 And elsewhere:
 
     my $account = BankAccount->new(balance => 100000);
